Acknowledgements
================

Many thanks to following people for the time spent helping with Asphalt's development:

* Alice Bevan-McGregor (brainstorming and documentation QA)
* Guillaume "Cman" Brun (brainstorming)
* Darin Gordon (brainstorming and documentation QA)
* Antti Haapala (brainstorming)
* Olli Paloheimo (Asphalt logo design).
